@@ -5,7 +5,6 @@ package Crypt::TEA_PP;
 use strict;
 use warnings;
 use utf8;
-use bigint;
 
 use Carp;
 use List::Util qw(all);
@@ -14,6 +13,14 @@ use vars qw ($VERSION);
 
 $VERSION = '0.03';
 
+use Config;
+BEGIN {
+    if ( not defined $Config{use64bitint} ) {
+        require bigint;
+        bigint->import;
+    }
+}
+
 
 my $DELTA = 0x9e3779b9;
 my $SUMATION = 0xc6ef3720;
@@ -139,7 +146,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.03
+version 0.0301
 
 =head1 SYNOPSIS
 
